iterationtools.iterate_notes_and_chords_in_expr
===============================================

.. autofunction:: abjad.tools.iterationtools.iterate_notes_and_chords_in_expr.iterate_notes_and_chords_in_expr
   :noindex:
